#!/etc/opt/openit/perl -w

use strict;

my $cfg = "/var/opt/openit/etc/acc_types";
my $old = "/var/opt/openit/etc/acc_types.old";
my $new = "/var/opt/openit/etc/acc_types.new";

# Only root can patch
if ( $< ne 0 ) {
    die "Error: Patching must be done as 'root'!\n";
}

open(IN, "$cfg") || die "Error: Unable to read old cfg '$cfg'!\n";
open(OUT, ">$new") || die "Error: Can't write new cfg '$new'!\n";

# Copy top definitions from old config util Total license use logfile
while(my $line = <IN>) {
    if($line =~ /Total.license.use.logfile/) {
        last;
    }
    print OUT $line;
}

# Print new data type definition
print OUT <<EOF
 (Total^license^use^logfile,
  ((Count,Record^Count,x,SUM),
   (Running^time,Running^time^in^hours,Hour,SUM),
   (Avg^in^use,Average^number^of^licenses^in^use,x,ABSAVG),
   (Max^in^use,Maximum^number^of^licenses^in^use,x,MAX),
   (Min^in^use,Minimum^number^of^licenses^in^use,x,MIN),
   (Avg^utilization,Average^utilization^of^licenses,x,ABSAVG),
   (Max^utilization,Maximum^utilization^of^licenses,x,MAX),
   (Min^utilization,Minimum^utilization^of^licenses,x,MIN),
   (Elapsed^time,Elapsed^license^time^in^hours,Hour,SUM),
   (Distinct,Always^one^for^each^extracted^unique^classification,x,IDENT)),
  (Product,
   Feature,
   Max^available^licenses,
   Used^licenses,
   Prime^time)
  ),

EOF
;

# Skip old license use log file
while(my $line = <IN>) {
    if($line =~ /Denied.license.logfile/) {
	print OUT $line; # Keep first line
	last;
    }
}

# Keep rest of file
while(my $line = <IN>) {
    print OUT $line;
}

close(IN);
close(OUT);

if( ! rename($cfg, $old)) {
    die "Error: Unable to previous config to '$old'!\n";
}

if( ! rename($new, $cfg)) {
    die "Error: Unable to rename new config to '$cfg'!\n";
}

exit 0;
